import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-codepipeline-merge-action",
    "2.3.0",
    __name__[0:-6],
    "cdk-codepipeline-merge-action@2.3.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
